OSSP CVS Repository

ossp - Difference in ossp-pkg/rc/rc.h versions 1.54 and 1.55
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/rc/rc.h 1.54 -> 1.55

--- rc.h 2003/06/30 15:09:46     1.54
+++ rc.h 2003/06/30 15:27:38     1.55
@@ -52,21 +52,22 @@
 
 /* Rc return codes */
 typedef enum {
-    RC_OK      = 0,  /* Success                  */
-    RC_ERR_0   = 1,  /* Error base               */
-    RC_ERR_USE = 2,  /* Usage error              */
-    RC_ERR_MEM = 3,  /* Memory error             */
-    RC_ERR_SYS = 4,  /* System error (see errno) */
-    RC_ERR_IO  = 5,  /* Input/output error       */
-    RC_ERR_INT = 6,  /* Internal error           */
-    RC_ERR_FNC = 7,  /* Func file not found      */
-    RC_ERR_DIR = 8,  /* Location dir not found   */
-    RC_ERR_RCF = 9,  /* Rc file not found        */
-    RC_ERR_TRM = 10, /* Request to terminate app */
-    RC_ERR_CFG = 11, /* Config or option failure */
-    RC_WRN_0   = 12, /* Warning base             */
-    RC_WRN_OWR = 13, /* Overwrite warning        */
-    RC_WRN_NUL = 14  /* NULL pointer warning     */
+    RC_OK      = 0,   /* Success                  */
+    RC_ERR_0   = 1,   /* Error base               */
+    RC_ERR_USE = 2,   /* Usage error              */
+    RC_ERR_MEM = 3,   /* Memory error             */
+    RC_ERR_SYS = 4,   /* System error (see errno) */
+    RC_ERR_IO  = 5,   /* Input/output error       */
+    RC_ERR_INT = 6,   /* Internal error           */
+    RC_ERR_FNC = 7,   /* Func file not found      */
+    RC_ERR_DIR = 8,   /* Location dir not found   */
+    RC_ERR_RCF = 9,   /* Rc file not found        */
+    RC_ERR_TRM = 10,  /* Request to terminate app */
+    RC_ERR_CFG = 11,  /* Config or option failure */
+    RC_ERR_ROOT = 12, /* Process must run as root */
+    RC_WRN_0   = 13,  /* Warning base             */
+    RC_WRN_OWR = 14,  /* Overwrite warning        */
+    RC_WRN_NUL = 15   /* NULL pointer warning     */
 } rc_return_t;
 
 /* Config function prototypes */

CVSTrac 2.0.1